@@ -45,6 +45,7 @@
 #' @param y_title specify title on the y axis. default "log(nUMI)"
 #' @param p_values Manually providing p-values for plotting, be aware of
 #' group size and if necessary make your test return the same amount of values
+#' @param random_seed parameter for random state initialisation
 #'
 #' @import ggplot2
 #' @import ggpubr
@@ -103,7 +104,8 @@ DO.VlnPlot <- function(
     step_mod = 0,
     hjust_test_2 = 0.5,
     vjust_test_2 = 0,
-    sign_bar = 0.8
+    sign_bar = 0.8,
+    random_seed = 42
 ) {
     # support for single cell experiment objects
     if (methods::is(sce_object, "SingleCellExperiment")) {
@@ -158,11 +160,11 @@ DO.VlnPlot <- function(
 
 
     vln_df$group <- factor(
-        vln_df[[group.by]],
+        vln_df$condition,
         levels = c(
             as.character(ctrl.condition),
-            levels(factor(vln_df[[group.by]]))[
-                !(levels(factor(vln_df[[group.by]])) %in% ctrl.condition)
+            levels(factor(vln_df$condition))[
+                !(levels(factor(vln_df$condition)) %in% ctrl.condition)
             ]
         )
     )
@@ -486,6 +488,9 @@ DO.VlnPlot <- function(
         ))
     }
 
+    #plotting with reproducibility
+    set.seed(random_seed)
+
     # normal violin
     if (is.null(group.by.2)) {
         p <- ggplot(vln_df, aes(x = condition, y = !!sym(Feature))) +
